@@ -209,7 +209,7 @@ gconf_cell_renderer_text_editing_done (GtkCellEditable *entry, GConfCellRenderer
 		gconf_value_set_string (value, new_text);
 		break;
 	case GCONF_VALUE_FLOAT:
-		gconf_value_set_float (value, (gint)(g_ascii_strtod (new_text, NULL)));
+		gconf_value_set_float (value, (gdouble)(g_ascii_strtod (new_text, NULL)));
 		break;
 	case GCONF_VALUE_INT:
 		gconf_value_set_int (value, (gint)(g_ascii_strtod (new_text, NULL)));
