@@ -187,7 +187,7 @@ gconf_editor_window_edit_bookmarks (gpointer callback_data, guint action, GtkWid
 	}
 	
 	dialog = gconf_bookmarks_dialog_new (GTK_WINDOW (callback_data));
-	g_object_add_weak_pointer (G_OBJECT (dialog), (gpointer *)&dialog);
+	g_object_add_weak_pointer (G_OBJECT (dialog), (gpointer)&dialog);
 	gtk_widget_show (dialog);
 }
 
@@ -197,7 +197,7 @@ gconf_editor_window_new_window (gpointer callback_data, guint action, GtkWidget
 	GtkWidget *new_window;
 
 	new_window = gconf_editor_application_create_editor_window ();
-	gtk_widget_show_all (new_window);
+	gtk_widget_show (new_window);
 }
 
 static void
@@ -457,8 +457,10 @@ gconf_editor_popup_window_edit_key (gpointer callback_data, guint action, GtkWid
 	GConfValue *value; 
 	char *path = NULL;
 	
-	gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)),
-					 NULL, &iter);
+	if (!gtk_tree_selection_get_selected (gtk_tree_view_get_selection (GTK_TREE_VIEW (window->list_view)),
+					      NULL, &iter))
+		return;
+	
 	gtk_tree_model_get (window->sorted_list_model, &iter,
 			    GCONF_LIST_MODEL_KEY_PATH_COLUMN, &path,
 			    GCONF_LIST_MODEL_VALUE_COLUMN, &value,
