@@ -6,6 +6,8 @@ typedef struct _Node Node;
 
 #define NODE(x) ((Node *)(x))
 
+static void gconf_tree_model_clear_node (GtkTreeModel *tree_model, Node *node);
+
 static GdkPixbuf *closed_icon;
 static GdkPixbuf *open_icon;
 
@@ -103,43 +105,17 @@ gconf_tree_model_get_gconf_name (GConfTreeModel *tree_model, GtkTreeIter *iter)
 	return g_strdup (ptr);
 }
 
-gchar *
-gconf_tree_model_get_gconf_escape_path (gchar *node_path)
-{
-	gchar *ptr;
-	gchar *escape_key;
-	gchar *escape_node_path;
-	gchar *node_dir;
-
-	ptr = node_path + strlen (node_path);
-
-	while (ptr[-1] != '/')
-		ptr--;
-
-	escape_key = gconf_escape_key (ptr, -1);
-
-	node_dir = g_strndup (node_path, ptr - node_path);
-	escape_node_path = g_strconcat (node_dir, escape_key, NULL);
-	g_free (node_dir);
-	g_free (escape_key);
-
-	return escape_node_path;
-
-}
 static gboolean
 gconf_tree_model_build_level (GConfTreeModel *model, Node *parent_node, gboolean emit_signals)
 {
 	GSList *list, *tmp;
 	Node *tmp_node = NULL;
 	gint i = 0;
-	gchar *escape_key;
 
 	if (parent_node->children)
 		return FALSE;
 
-	escape_key = gconf_tree_model_get_gconf_escape_path (parent_node->path);
-	list = gconf_client_all_dirs (model->client, escape_key, NULL);
-	g_free (escape_key);
+	list = gconf_client_all_dirs (model->client, parent_node->path, NULL);
 
 	if (!list)
 		return FALSE;
@@ -150,8 +126,7 @@ gconf_tree_model_build_level (GConfTreeModel *model, Node *parent_node, gboolean
 		node = g_new0 (Node, 1);
 		node->offset = i;
 		node->parent = parent_node;
-		node->path = gconf_unescape_key (tmp->data, -1);
-		g_free (tmp->data);
+		node->path = tmp->data;
 
 		if (tmp_node) {
 			tmp_node->next = node;
@@ -428,11 +403,8 @@ gconf_tree_model_iter_has_child (GtkTreeModel *tree_model, GtkTreeIter *iter)
 	GConfTreeModel *model = (GConfTreeModel *)tree_model;
 	Node *node = iter->user_data;
 	GSList *list;
-	gchar *escape_key;
 
-	escape_key = gconf_tree_model_get_gconf_escape_path (node->path);
-	list = gconf_client_all_dirs (model->client, escape_key, NULL);
-	g_free (escape_key);
+	list = gconf_client_all_dirs (model->client, node->path, NULL);
 
 	if (list == NULL)
 		return FALSE;
@@ -449,24 +421,37 @@ gconf_tree_model_ref_node (GtkTreeModel *tree_model, GtkTreeIter *iter)
 	node->ref_count += 1;
 }
 
+static void
+gconf_tree_model_free_node (GtkTreeModel *tree_model, Node *node)
+{
+	gconf_tree_model_clear_node (tree_model, node);
+	if (node->path)
+		g_free (node->path);
+	g_free (node);
+}
+
+static void
+gconf_tree_model_clear_node (GtkTreeModel *tree_model, Node *node)
+{
+	Node *children;
+
+	children = node->children;
+	node->children = NULL;
+	while (children) {
+		Node *next = children->next;
+		gconf_tree_model_free_node (tree_model, children);
+		children = next;
+	}
+}
+
 static void
 gconf_tree_model_unref_node (GtkTreeModel *tree_model, GtkTreeIter *iter)
 {
 	Node *node = iter->user_data;
 	node->ref_count -= 1;
 
-	if (node->ref_count == 0) {
-
-		if ((node->parent != NULL) && (node->parent->children == node))
-			node->parent->children = node->children;
-		if (node->next != NULL)
-			node->next->prev = node->prev;
-		if (node->prev != NULL)
-			node->prev->next = node->next;
-
-		g_free (node->path);
-		g_free (node);
-	}
+	if (node->ref_count == 0)
+		gconf_tree_model_clear_node (tree_model, node);
 }
 
 static void
